<?php
/*
 * CUSTOM POST TYPE TEMPLATE
 *
 * This is the custom post type post template. If you edit the post type name, you've got
 * to change the name of this template to reflect that name change.
 *
 * For Example, if your custom post type is "register_post_type( 'bookmarks')",
 * then your single template should be single-bookmarks.php
 *
 * Be aware that you should rename 'custom_cat' and 'custom_tag' to the appropiate custom
 * category and taxonomy slugs, or this template will not finish to load properly.
 *
 * For more info: http://codex.wordpress.org/Post_Type_Templates
*/
?>

<?php get_header(); // Header ?>
<!-- #content -->
<div id="content">
	<!-- #inner-content -->
	<div id="inner-content">
		<!-- #main -->
		<main id="main" role="main" itemscope itemprop="mainContentOfPage" itemtype="http://schema.org/Blog">

			<?php if (have_posts()) : while (have_posts()) : the_post(); ?>

			<article id="post-<?php the_ID(); ?>" <?php post_class('section section--alternate'); ?> role="article">

				<!-- Back link -->
				<div class="menu-inner-wrapper js-menu-inner-wrapper wow fadeInUp">
					<div class="row">
						<div class="large-12 column">
							<ul class="menu menu--inner">
								<li>
										<?php printf('<a class="link" href="%1$s" title="%3$s">%2$s</a>', get_post_type_archive_link('sake'), __('&laquo; Back', 'kalabera'), __('Back to Our Sake', 'kalabera')); ?>
								</li>
							</ul>
						</div>
					</div>
				</div> <!-- end of: Back link -->

				<!-- Spacer -->
				<div class="sake__spacer"></div> <!-- end of: Spacer -->

        <div class="row" data-equalizer>
          <!-- Sake image -->
          <div class="large-3 large-push-2 medium-4 medium-push-1 column">
            <div class="sake__image text-center medium-text-right wow fadeIn" data-wow-duration="1.5s" data-equalizer-watch>
            	<?php the_post_thumbnail(
										array(237, 450)
								); ?>
            </div>
          </div> <!-- end of: Sake image -->

          <!-- Sake info -->
          <div class="large-6 medium-6 column">
						<div class="sake__content sake__preview" data-equalizer-watch>
							<header class="section__header">
	              <?php the_title('<h3 class="sake__title wow fadeInUp">', '</h3>'); ?>

	              <span class="sake__price wow fadeInUp"><?php the_field('price'); ?></span>
	            </header>

	            <div class="sake__description wow fadeInUp"><?php the_content(); ?></div>
						</div>
          </div> <!-- end of: Sake -->

        </div>
			</article>

      <?php // Retrieve related sake
        $sake_terms = wp_get_object_terms(get_the_ID(), 'sake-tag', array('fields' => 'ids'));
        // WP_Query arguments
        $args = array(
          'post_type' => 'sake',
          'post_status' => 'publish',
          'posts_per_page' => 3,
          'orderby' => 'date',
          'tax_query' => array(
            array(
              'taxonomy' => 'sake-tag',
              'field' => 'id',
              'terms' => $sake_terms
            )
          ),
          'post__not_in' => array(get_the_ID()) // exclude the current sake
        );

        $related = new WP_Query($args); // initialize a new WP_Query object
        if($related->have_posts()) :
				$total = 0;?>

	      <!-- You may like -->
	      <section class="section related">
	        <header class="section__header">
	          <div class="row">
	            <div class="large-12 column text-center">
	              <h2 class="related__title h6 wow fadeInUp"><?php _e('You May Like', 'kalabera'); ?></h2>
	            </div>
	          </div>
	        </header>
          <div class="row" data-equalizer data-equalize-on="medium">
            <?php while($related->have_posts()) :
							$related->the_post();
							$total++; // increment total
						?>
            <div class="large-4 medium-6 column <?php echo ($total == $related->post_count) ? 'end' : ''; ?>">
              <article id="sake-<?php the_ID(); ?>" <?php post_class(); ?> data-equalizer-watch>
                <?php if(has_post_thumbnail()) : ?>
                  <a class="wow fadeIn"
										href="<?php the_permalink(); ?>"
										title="<?php the_title_attribute(); ?>"
										data-wow-duration='1.5s'><?php the_post_thumbnail(array(196, 370)); ?></a>
                <?php endif; ?>

                <h3 class="sake__title text-center wow fadeInUp"><a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>"><?php the_title(); ?></a></h3>

                <span class="sake__price wow fadeInUp"><?php the_field('price'); ?></span>
              </article>
            </div>
            <?php endwhile; ?>
          </div>
				</section>
        <?php endif;
      	wp_reset_postdata(); // reset the global $post object
      ?>
      </section>

			<?php endwhile; ?>

			<?php else : ?>

				<?php get_template_part('broken'); ?>

			<?php endif; ?>

		</main> <!-- end of: #main -->

	</div> <!-- end of: #inner-content -->

</div> <!-- end of: #content -->

<?php get_footer(); // Footer ?>
