<?php
/**
** A base module for the following types of tags:
**  [text] and [text*]    # Single-line text
**  [email] and [email*]  # Email address
**  [url] and [url*]    # URL
**  [tel] and [tel*]    # Telephone number
**/

/* Validation filter */

// remove Contact Form7 default text validation filters
remove_filter( 'wpcf7_validate_text', 'wpcf7_text_validation_filter');
remove_filter( 'wpcf7_validate_text*', 'wpcf7_text_validation_filter');
remove_filter( 'wpcf7_validate_email', 'wpcf7_text_validation_filter');
remove_filter( 'wpcf7_validate_email*', 'wpcf7_text_validation_filter');
remove_filter( 'wpcf7_validate_url', 'wpcf7_text_validation_filter');
remove_filter( 'wpcf7_validate_url*', 'wpcf7_text_validation_filter');
remove_filter( 'wpcf7_validate_tel', 'wpcf7_text_validation_filter');
remove_filter( 'wpcf7_validate_tel*', 'wpcf7_text_validation_filter');

add_filter( 'wpcf7_validate_text', 'kalabera_text_validation_filter', 10, 2 );
add_filter( 'wpcf7_validate_text*', 'kalabera_text_validation_filter', 10, 2 );
add_filter( 'wpcf7_validate_email', 'kalabera_text_validation_filter', 10, 2 );
add_filter( 'wpcf7_validate_email*', 'kalabera_text_validation_filter', 10, 2 );
add_filter( 'wpcf7_validate_url', 'kalabera_text_validation_filter', 10, 2 );
add_filter( 'wpcf7_validate_url*', 'kalabera_text_validation_filter', 10, 2 );
add_filter( 'wpcf7_validate_tel', 'kalabera_text_validation_filter', 10, 2 );
add_filter( 'wpcf7_validate_tel*', 'kalabera_text_validation_filter', 10, 2 );

function kalabera_text_validation_filter( $result, $tag ) {
  $tag = new WPCF7_Shortcode( $tag );

  $name = $tag->name;

  $value = isset( $_POST[$name] )
    ? trim( wp_unslash( strtr( (string) $_POST[$name], "\n", " " ) ) )
    : '';

  if ( 'text' == $tag->basetype ) {

    // for input named 'name'
    if('name' == $name && $tag->is_required() && '' == $value) {
        $result->invalidate($tag, __('Name is required.', 'kalabera'));
    }

    // for input named 'subject'
    if('subject' == $name && $tag->is_required() && '' == $value) {
        $result->invalidate($tag, __('Subject is required.', 'kalabera'));
    }

    if ( $tag->is_required() && '' == $value ) {
      $result->invalidate( $tag, wpcf7_get_message( 'invalid_required' ) );
    }

  }

  if ( 'email' == $tag->basetype ) {
    // for input named 'email'
    if('email' == $name && $tag->is_required() && '' == $value) {
        $result->invalidate($tag, __('Email is required.', 'kalabera'));
    }

    if ( $tag->is_required() && '' == $value ) {
      $result->invalidate( $tag, wpcf7_get_message( 'invalid_required' ) );
    } elseif ( '' != $value && ! wpcf7_is_email( $value ) ) {
      $result->invalidate( $tag, wpcf7_get_message( 'invalid_email' ) );
    }
  }

  if ( 'url' == $tag->basetype ) {
    if ( $tag->is_required() && '' == $value ) {
      $result->invalidate( $tag, wpcf7_get_message( 'invalid_required' ) );
    } elseif ( '' != $value && ! wpcf7_is_url( $value ) ) {
      $result->invalidate( $tag, wpcf7_get_message( 'invalid_url' ) );
    }
  }

  if ( 'tel' == $tag->basetype ) {
    if ( $tag->is_required() && '' == $value ) {
      $result->invalidate( $tag, wpcf7_get_message( 'invalid_required' ) );
    } elseif ( '' != $value && ! wpcf7_is_tel( $value ) ) {
      $result->invalidate( $tag, wpcf7_get_message( 'invalid_tel' ) );
    }
  }

  if ( ! empty( $value ) ) {
    $maxlength = $tag->get_maxlength_option();
    $minlength = $tag->get_minlength_option();

    if ( $maxlength && $minlength && $maxlength < $minlength ) {
      $maxlength = $minlength = null;
    }

    $code_units = wpcf7_count_code_units( $value );

    if ( false !== $code_units ) {
      if ( $maxlength && $maxlength < $code_units ) {
        $result->invalidate( $tag, wpcf7_get_message( 'invalid_too_long' ) );
      } elseif ( $minlength && $code_units < $minlength ) {
        $result->invalidate( $tag, wpcf7_get_message( 'invalid_too_short' ) );
      }
    }
  }

  return $result;
}
